 /**
 ***************************************************************************** 
   @example  AD5421.h
   @brief    This file contains functions written for the ADuCM360 that excercise the AD5421 via the SPI1 bus.
   @version  V0.2
   @author   ADI
   @date     January 2013

   @par Revision History:
   - V0.1, May 2012: initial version. 
   - V0.2, January 2013: added Doxygen comments

All files for ADuCM360/361 provided by ADI, including this file, are
provided  as is without warranty of any kind, either expressed or implied.
The user assumes any and all risk from the use of this code.
It is the responsibility of the person integrating this code into an application
to ensure that the resulting application performs as required and is safe.

**/

 void AD5421INIT(void);								                // Init. ADuCM360 to AD5421 interface.
 void AD5421_WriteToDAC(unsigned long ulDACValue);	   	// Write to IDAC data register
 void AD5421_WriteToCon(unsigned long ulConValue);	  	// Write to IDAC Control register
 void AD5421_WriteToOffAdj(unsigned long ulOffAdjValue);// Write to IDAC Offset adjust register
 void AD5421_WriteToGnAdj(unsigned long ulDACValue);	  // Write to IDAC Gain adjust register
 void AD5421_LoadDac(void);								              // Load the IDAC output
 void AD5421_ForceAlarm(void);							            // force Alarm condition on IDAC output
 void AD5421_Reset(void);								                // Reset AD5421
 void AD5421_InitADC(void);								              // Measure Vloop or die temp via ADC
 unsigned long AD5421_ReadDAC(unsigned long ulDACValue);// Read to IDAC data register
 unsigned long  AD5421_ReadCon(unsigned long ulConValue);// Read IDAC Control register
 void AD5421_ReadOffAdj(unsigned long ulOffAdjValue);	  // Read IDAC Offset adjust register
 void AD5421_ReadGnAdj(unsigned long ulDACValue);		    // Read IDAC Gain adjust register
 unsigned long  AD5421_ReadFault(unsigned long ulDACValue);// Read Fault register

 #define WRITEDAC 			1
 #define WRITECON 			2
 #define WRITEOFFADJ		3
 #define WRITEGNADJ 		4
 #define LOADDAC 			5
 #define FORCEALARM 		6
 #define AD5421RESET 		7
 #define INITADC 			8
 #define READDAC 			0x81
 #define READCON 			0x82
 #define READOFFADJ			0x83
 #define READGNADJ 			0x84
 #define READFAULT 			0x85

 static unsigned long ul5421CON __attribute__((unused)) = 0;
 static unsigned long ul5421DAT __attribute__((unused)) = 0;
 static unsigned long ul5421FAULT __attribute__((unused)) = 0;
